==> dophon_db-1.2.4a1-py3-none-any.whl: dophon_db/orm/query_structor.py <==
from dophon_db.mysql import Pool, Connection
from dophon_db import mysql
from dophon import logger

"""
查询语句结构映射

结构:
select
<Field>
from
<tables>
where
<param_dicts>
<sort_param>
"""
pool = Pool.get_pool()

logger.inject_logger(globals())


class Selelct:
    """
    查询结构类
    """

    def before_select(self, fields_list: list, has_where: bool) -> str:
        result = 'SELECT ' + \
                 (getattr(self, 'fields')(fields_list) if fields_list else ' * ') + \
                 ' FROM ' + \
                 (

                     getattr(self, 'table_map_key') + \
                     (
                         (' AS ' + getattr(self, '__alias'))
                         if getattr(self, '__alias') != getattr(self, 'table_map_key') else ''
                     )
                     if not hasattr(self, '__join_list') else (getattr(self, 'exe_join')())
                 ) \
                 + \
                 (getattr(self, 'where')() if has_where else '')
        return result

    def select(self, fields: list = [], has_where: bool = True) -> list:
        """
        查询并获取该表结果集
        :param fields: 列参
        :return: <list> 多条结果列表
        """
        sql = self.before_select(fields, has_where)
        logger.info('执行: %s', sql)
        result = []
        connection = pool.getConn().getConnect()
        cursor = connection.cursor()
        cursor.execute(sql)
        if not sql.startswith('select') and not sql.startswith('SELECT'):
            data = [[cursor.rowcount]]
            description = [['row_count']]
        else:
            data = cursor.fetchall()
            description = cursor.description
        connection.commit()
        result = mysql.sort_result(data, description, result)
        return result

    def select_one(self, fields: list = []) -> dict:
        """
        查询一条结果集
        :param fields: 列参
        :return: <dict> 单条结果集字典
        """
        if hasattr(self, '__field_callable_list') and len(getattr(self, '__field_callable_list')) > 0:
            # 存在可生成的查询条件
            result = self.select(fields=fields)
            if len(result) == 1:
                return result
            elif len(result) > 1:
                logger.error('过多结果集')
                raise Exception('过多结果集')
            else:
                return None
        else:
            logger.error('无法预料的唯一结果集,找不到查询过滤条件')
            raise Exception('无法预料的唯一结果集,找不到查询过滤条件')

    def select_all(self, fields: list = [], ignore_fields_warning: bool = True) -> list:
        """
        同select
        :param fields:
        :return:
        """
        if not ignore_fields_warning and hasattr(self, '__field_callable_list') and len(getattr(self, '__field_callable_list')) > 0:
            logger.warning('警告:存在查询过滤条件 %s ', str(getattr(self, '__field_callable_list')))
        return self.select(fields=fields, has_where=False)


class Insert:
    """
    新增结构类
    """

    def before_insert(self):
        result = 'INSERT INTO ' + \
                 getattr(self, 'table_map_key') + ' ' + \
                 getattr(self, 'values')()
        # print(result)
        return result

    def insert(self) -> int:
        """
        新增结果集
        :return: <int> 影响行数
                [{'row_count': '0'}]
        """
        sql = self.before_insert()
        logger.info('执行: %s', sql)
        result = []
        connection = pool.getConn().getConnect()
        cursor = connection.cursor()
        try:
            cursor.execute(sql)
            if not sql.startswith('select') and not sql.startswith('SELECT'):
                data = [[cursor.rowcount]]
                description = [['row_count']]
            else:
                data = cursor.fetchall()
                description = cursor.description
            connection.commit()
            result = mysql.sort_result(data, description, result)[0]['row_count']
            return int(result)
        except Exception as e:
            logger.error('%s', e)
            connection.rollback()
            return 0


class Update():
    """
    更新结构类
    """

    def before_update(self, update: list, where: list):
        result = 'UPDATE ' + getattr(self, 'table_map_key') + \
                 (
                     (' AS ' + getattr(self, '__alias'))
                     if getattr(self, '__alias') != getattr(self, 'table_map_key') else ''
                 ) + \
                 getattr(self, 'set')(update) + \
                 getattr(self, 'where')(where)
        # print(result)
        return result

    def update(self, update: list = [], where: list = []) -> int:
        """
        更新结果集
        :param update: 更新列参
        :param where: 条件列参
        :return: <int> 影响行数
        """
        sql = self.before_update(update, where)
        logger.info('执行: %s', sql)
        result = []
        connection = pool.getConn().getConnect()
        cursor = connection.cursor()
        try:
            cursor.execute(sql)
            if not sql.startswith('select') and not sql.startswith('SELECT'):
                data = [[cursor.rowcount]]
                description = [['row_count']]
            else:
                data = cursor.fetchall()
                description = cursor.description
            connection.commit()
            result = mysql.sort_result(data, description, result)[0]['row_count']
            return int(result)
        except Exception as e:
            logger.error('%s', e)
            connection.rollback()
            return 0


class Delete():
    """
    删除结构类
    """

    def before_delete(self, where: list):
        result = 'DELETE FROM ' + getattr(self, 'table_map_key') + \
                 ' ' + getattr(self, 'where')(where, be_alias=False)
        # print(result)
        return result

    def delete(self, where: list = []) -> int:
        """
        删除结果集

        :param where: 条件列参
        :return: <int> 影响行数
        """
        sql = self.before_delete(where)
        logger.info('执行: %s', sql)
        result = []
        connection = pool.getConn().getConnect()
        cursor = connection.cursor()
        try:
            cursor.execute(sql)
            if not sql.startswith('select') and not sql.startswith('SELECT'):
                data = [[cursor.rowcount]]
                description = [['row_count']]
            else:
                data = cursor.fetchall()
                description = cursor.description
            connection.commit()
            result = mysql.sort_result(data, description, result)[0]['row_count']
            return int(result)
        except Exception as e:
            logger.error('%s', e)
            connection.rollback()
            return 0


class Struct(Selelct, Insert, Update, Delete):
    """
    查询语句结构类
    """

==> dophon_db-1.2.5.post2-py3-none-any.whl: dophon_db/orm/query_structor.py <==
from dophon_db import utils

from dophon_logger import *

logger = get_logger(DOPHON)

"""
查询语句结构映射

结构:
select
<Field>
from
<tables>
where
<param_dicts>
<sort_param>
"""

logger.inject_logger(globals())


def get_connection(target):
    """
    从连接池中获取连接
    :return:
    """
    return target.pool_getter().getConn()


class Selelct:
    """
    查询结构类
    """

    def before_select(self, fields_list: list, has_where: bool) -> str:
        result = 'SELECT ' + \
                 (getattr(self, 'fields')(fields_list) if fields_list else ' * ') + \
                 ' FROM ' + \
                 (

                     getattr(self, 'table_map_key') + \
                     (
                         (' AS ' + getattr(self, '__alias'))
                         if getattr(self, '__alias') != getattr(self, 'table_map_key') else ''
                     )
                     if not hasattr(self, '__join_list') else (getattr(self, 'exe_join')())
                 ) \
                 + \
                 (getattr(self, 'where')() if has_where else '')
        return result

    def select(self, fields: list = [], has_where: bool = True) -> list:
        """
        查询并获取该表结果集
        :param fields: 列参
        :return: <list> 多条结果列表
        """
        sql = self.before_select(fields, has_where)
        logger.info('执行: %s', sql)
        result = []
        connection = get_connection(self)
        cursor = connection.cursor()
        cursor.execute(sql)
        if not sql.startswith('select') and not sql.startswith('SELECT'):
            data = [[cursor.rowcount]]
            description = [['row_count']]
        else:
            data = cursor.fetchall()
            description = cursor.description
        connection.commit()
        result = utils.sort_result(data, description, result)
        return result

    def select_one(self, fields: list = []) -> dict:
        """
        查询一条结果集
        :param fields: 列参
        :return: <dict> 单条结果集字典
        """
        if hasattr(self, '__field_callable_list') and len(getattr(self, '__field_callable_list')) > 0:
            # 存在可生成的查询条件
            result = self.select(fields=fields)
            if len(result) == 1:
                return result
            elif len(result) > 1:
                logger.error('过多结果集')
                raise Exception('过多结果集')
            else:
                return None
        else:
            logger.error('无法预料的唯一结果集,找不到查询过滤条件')
            raise Exception('无法预料的唯一结果集,找不到查询过滤条件')

    def select_all(self, fields: list = [], ignore_fields_warning: bool = True) -> list:
        """
        同select
        :param fields:
        :return:
        """
        if not ignore_fields_warning and hasattr(self, '__field_callable_list') and len(
                getattr(self, '__field_callable_list')) > 0:
            logger.warning('警告:存在查询过滤条件 %s ', str(getattr(self, '__field_callable_list')))
        return self.select(fields=fields, has_where=False)


class Insert:
    """
    新增结构类
    """

    def before_insert(self):
        result = 'INSERT INTO ' + \
                 getattr(self, 'table_map_key') + ' ' + \
                 getattr(self, 'values')()
        return result

    def insert(self) -> int:
        """
        新增结果集
        :return: <int> 影响行数
                [{'row_count': '0'}]
        """
        sql = self.before_insert()
        logger.info('执行: %s', sql)
        result = []
        connection = get_connection(self)
        cursor = connection.cursor()
        try:
            cursor.execute(sql)
            if not sql.startswith('select') and not sql.startswith('SELECT'):
                data = [[cursor.rowcount]]
                description = [['row_count']]
            else:
                data = cursor.fetchall()
                description = cursor.description
            connection.commit()
            result = utils.sort_result(data, description, result)[0]['row_count']
            return int(result)
        except Exception as e:
            logger.error('%s', e)
            connection.rollback()
            return 0


class Update():
    """
    更新结构类
    """

    def before_update(self, update: list, where: list):
        result = 'UPDATE ' + getattr(self, 'table_map_key') + \
                 (
                     (' AS ' + getattr(self, '__alias'))
                     if getattr(self, '__alias') != getattr(self, 'table_map_key') else ''
                 ) + \
                 getattr(self, 'set')(update) + \
                 getattr(self, 'where')(where)
        return result

    def update(self, update: list = [], where: list = []) -> int:
        """
        更新结果集
        :param update: 更新列参
        :param where: 条件列参
        :return: <int> 影响行数
        """
        sql = self.before_update(update, where)
        logger.info('执行: %s', sql)
        result = []
        connection = get_connection(self)
        cursor = connection.cursor()
        try:
            cursor.execute(sql)
            if not sql.startswith('select') and not sql.startswith('SELECT'):
                data = [[cursor.rowcount]]
                description = [['row_count']]
            else:
                data = cursor.fetchall()
                description = cursor.description
            connection.commit()
            result = utils.sort_result(data, description, result)[0]['row_count']
            return int(result)
        except Exception as e:
            logger.error('%s', e)
            connection.rollback()
            return 0


class Delete():
    """
    删除结构类
    """

    def before_delete(self, where: list):
        result = 'DELETE FROM ' + getattr(self, 'table_map_key') + \
                 ' ' + getattr(self, 'where')(where, be_alias=False)
        return result

    def delete(self, where: list = []) -> int:
        """
        删除结果集

        :param where: 条件列参
        :return: <int> 影响行数
        """
        sql = self.before_delete(where)
        logger.info('执行: %s', sql)
        result = []
        connection = get_connection(self)
        cursor = connection.cursor()
        try:
            cursor.execute(sql)
            if not sql.startswith('select') and not sql.startswith('SELECT'):
                data = [[cursor.rowcount]]
                description = [['row_count']]
            else:
                data = cursor.fetchall()
                description = cursor.description
            connection.commit()
            result = utils.sort_result(data, description, result)[0]['row_count']
            return int(result)
        except Exception as e:
            logger.error('%s', e)
            connection.rollback()
            return 0


class Struct(Selelct, Insert, Update, Delete):
    """
    查询语句结构类
    """
